@@ -10,7 +10,6 @@ describe 'heat::engine' do
       :heat_waitcondition_server_url       => 'http://127.0.0.1:8000/v1/waitcondition',
       :engine_life_check_timeout           => '<SERVICE DEFAULT>',
       :trusts_delegated_roles              => '<SERVICE DEFAULT>',
-      :deferred_auth_method                => '<SERVICE DEFAULT>',
       :default_software_config_transport   => '<SERVICE DEFAULT>',
       :default_deployment_signal_transport => '<SERVICE DEFAULT>',
       :default_user_data_format            => '<SERVICE DEFAULT>',
@@ -21,6 +20,7 @@ describe 'heat::engine' do
       :max_nested_stack_depth              => '<SERVICE DEFAULT>',
       :plugin_dirs                         => '<SERVICE DEFAULT>',
       :client_retry_limit                  => '<SERVICE DEFAULT>',
+      :server_keystone_endpoint_type       => '<SERVICE DEFAULT>',
     }
   end
 
@@ -51,6 +51,7 @@ describe 'heat::engine' do
         :environment_dir                     => '/etc/heat/environment.d',
         :template_dir                        => '/etc/heat/templates',
         :client_retry_limit                  => 2,
+        :server_keystone_endpoint_type       => 'public',
       }
     ].each do |new_params|
       describe 'when #{param_set == {} ? "using default" : "specifying"} parameters'
@@ -90,6 +91,7 @@ describe 'heat::engine' do
       it { is_expected.to contain_heat_config('DEFAULT/default_user_data_format').with_value( expected_params[:default_user_data_format] ) }
       it { is_expected.to contain_heat_config('DEFAULT/instance_connection_is_secure').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('DEFAULT/instance_connection_https_validate_certificates').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_heat_config('DEFAULT/max_stacks_per_tenant').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('DEFAULT/max_resources_per_stack').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('DEFAULT/num_engine_workers').with_value( expected_params[:num_engine_workers] ) }
       it { is_expected.to contain_heat_config('DEFAULT/convergence_engine').with_value( expected_params[:convergence_engine] ) }
@@ -98,6 +100,18 @@ describe 'heat::engine' do
       it { is_expected.to contain_heat_config('DEFAULT/template_dir').with_value( expected_params[:template_dir] ) }
       it { is_expected.to contain_heat_config('DEFAULT/plugin_dirs').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_heat_config('DEFAULT/client_retry_limit').with_value( expected_params[:client_retry_limit] ) }
+      it { is_expected.to contain_heat_config('DEFAULT/server_keystone_endpoint_type').with_value( expected_params[:server_keystone_endpoint_type] ) }
+    end
+
+    context 'with max limits are defined' do
+      before do
+        params.merge!({
+          :max_stacks_per_tenant   => 512,
+          :max_resources_per_stack => 1000,
+        })
+      end
+      it { is_expected.to contain_heat_config('DEFAULT/max_stacks_per_tenant').with_value(512) }
+      it { is_expected.to contain_heat_config('DEFAULT/max_resources_per_stack').with_value(1000) }
     end
 
     context 'with disabled service managing' do
@@ -107,14 +121,7 @@ describe 'heat::engine' do
           :enabled        => false })
       end
 
-      it { is_expected.to contain_service('heat-engine').with(
-        :ensure     => nil,
-        :name       => platform_params[:service_name],
-        :enable     => false,
-        :hasstatus  => 'true',
-        :hasrestart => 'true',
-        :tag        => 'heat-service',
-      ) }
+      it { is_expected.to_not contain_service('heat-engine') }
     end
 
     context 'with plugin_dirs value set' do
